Installation
============

.. note::

   This is an abridged version of the core SteelScript installation. It is meant to
   focus on getting SteelScript Wireshark installed as quickly as possible.
   For the full documentation on SteelScript's installation,
   `click here <../index.html>`_.
  

1. Verify the following:

   * You have **Python 2.7** installed
   * You have ``pip`` installed 
   * You have set up a virtual enviornment to install SteelScript.

2. Run ``pip install steelscript`` to install the core SteelScript package.
3. Run ``steel install`` to install the core SteelScript modules, including `steelscript-wireshark`.


Continue to `Getting Started <getting-started.html>`_ for next steps.
